use Test::More tests => 1;

BEGIN {
  use_ok('Catalyst::Plugin::Static::Simple::ByClass');
}

diag( "Testing Catalyst::Plugin::Static::Simple::ByClass $Catalyst::Plugin::Static::Simple::ByClass::VERSION" );
